###
# Copyright (c) 2005, Daniel DiPaolo
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright notice,
#     this list of conditions, and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions, and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#   * Neither the name of the author of this software nor the name of
#     contributors to this software may be used to endorse or promote products
#     derived from this software without specific prior written consent.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
###

from supybot.test import *
import supybot.ircutils as ircutils

class ReplyTestCase(ChannelPluginTestCase):
    plugins = ('Reply',)
    def testPrivate(self):
        m = self.getMsg('private [list]')
        self.failIf(ircutils.isChannel(m.args[0]))

    def testNotice(self):
        m = self.getMsg('notice [list]')
        self.assertEqual(m.command, 'NOTICE')

    def testNoticePrivate(self):
        m = self.assertNotError('notice [private [list]]')
        self.assertEqual(m.command, 'NOTICE')
        self.assertEqual(m.args[0], self.nick)
        m = self.assertNotError('private [notice [list]]')
        self.assertEqual(m.command, 'NOTICE')
        self.assertEqual(m.args[0], self.nick)

    def testReplies(self):
        self.assertResponse('replies a b c', 'a, b, and c')
        self.assertNotError('config channel supybot.reply.oneToOne False')
        self.assertResponse('replies a b c', 'a')
        self.assertResponse(' ', 'b')
        self.assertResponse(' ', 'c')
        self.assertNotError('config channel supybot.reply.oneToOne True')

class ReplyNonChannelTestCase(PluginTestCase):
    plugins = ('Reply',)
    def testAction(self):
        self.prefix = 'something!else@somewhere.else'
        self.nick = 'something'
        m = self.assertAction('action foo', 'foo')
        self.failIf(m.args[0] == self.irc.nick)

# vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
